@@ -1,7 +1,7 @@
 from defusedxml.ElementTree import XML
 
 from myprss import logger
-from myprss.utils import parse_from_rfc822_to_date
+from myprss.utils import parse_from_rfc822_to_date, parse_url
 
 
 def parse_rss_content(data):
@@ -23,7 +23,7 @@ def parse_rss_content(data):
             {
                 "date": parse_from_rfc822_to_date(item.find("pubDate").text),
                 "title": item.find("title").text,
-                "url": item.find("link").text,
+                "url": parse_url(item.find("link").text),
                 "description": item.find("description").text,
             }
         )
