@@ -1,4 +1,5 @@
 import re
+import urllib
 
 from email.utils import parsedate_to_datetime
 
@@ -18,5 +19,11 @@ def parse_from_rfc822_to_date(date):
 
     return parsedate_to_datetime(date)
 
+
 def parse_from_date_to_rfc822_with_tz(date):
     return date.astimezone().strftime("%a, %d %b %Y %H:%M:%S")
+
+
+def parse_url(url):
+    parsed = urllib.parse.urlparse(url)
+    return f"{parsed.scheme}://{parsed.hostname}{parsed.path}"
